==> vaulter-py-0.0.1.tar.gz: vaulter-py-0.0.1/README.md <==
# **VAULTERPY**
### _SAFE YOUR PASSWORDS_

***VAULTERPY** is a python program with which you can secure your precious passwords very easily.*

## Features
- Stores your passwords in database
- All the passwords are encrypted 
- You can only decrypt your passwords if you have the right key
- The application can run on any **OS** - *windows, linux, apple, etc.*

## Motivation
> My motive of building this applcation
> is to help others as well as me
> for storing passwords without any tension 
> And not to use any notebook or papers,
> to write my passwords as it can be seen by other easily.😧

## Tech
The overall configuration of my project and libraries which I have used :-

- Written in -**Python** language
- Libraries - 
    - **Cryptography** - Used for encrypting and decrypting the passwords
    - **Sqlite3** - Used for working with database and storing the passwords
- Made an env - environment for this project, so made a precise requirements.txt
- requirements.txt

## Installation
The Installation is pretty easy.
- Make a directory in your computer to store the files.
- Go into the directory and clone the git repository
```
git clone https://github.com/Shreejan-35/PYVAULT.git
```
- Then go int the *src* directory.
- Open your favourite terminal, and type this commands
```
pip install requirements.txt
```
Then,
```
python run.py
```
OR
```
python3 run.py
```

# Useful guide
Before inserting or retriving passwords, press **L** to load your secret key.

# Others
See the test directory in src to see some previous passwords which I stored in the database and also the key which is generated.

# License
MIT License

***FOLLOW ME ON INSTAGRAM @star_cyber_warrior***

==> vaulter-py-0.0.2.tar.gz: vaulter-py-0.0.2/README.md <==
# **VAULTERPY**
### _SAFE YOUR PASSWORDS_

***VAULTERPY** is a python program with which you can secure your precious passwords very easily.*

## Features
- Stores your passwords in database
- All the passwords are encrypted 
- You can only decrypt your passwords if you have the right key
- The application can run on any **OS** - *windows, linux, apple, etc.*

## Motivation
> My motive of building this applcation
> is to help others as well as me
> for storing passwords without any tension 
> And not to use any notebook or papers,
> to write my passwords as it can be seen by other easily.😧

## Tech
The overall configuration of my project and libraries which I have used :-

- Written in -**Python** language
- Libraries - 
    - **Cryptography** - Used for encrypting and decrypting the passwords
    - **Sqlite3** - Used for working with database and storing the passwords
- Made an env - environment for this project, so made a precise requirements.txt
- requirements.txt

## Installation
The Installation is pretty easy.
- Using Git
    - Make a directory in your computer to store the files.
    - Go into the directory and clone the git repository
    ```
    git clone https://github.com/Shreejan-35/VAULTERPY.git
    ```
    - Then go int the *src* directory.
    - Open your favourite terminal, and type this commands
    ```
    pip install requirements.txt
    ```
    Then,
    ```
    python run.py
    ```
    OR
    ```
    python3 run.py
    ```

- Using pip

Run the following command -
```
pip install vaulter-py
```
OR
```
pip3 install vaulter-py
```

Then run,
```
vaulterpy
```

# Useful guide
Before inserting or retriving passwords, press **L** to load your secret key.

# Others
See the test directory in src to see some previous passwords which I stored in the database and also the key which is generated.

# License
MIT License

***FOLLOW ME ON INSTAGRAM @star_cyber_warrior***
